#
# spec file for package wire
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} == 8
%global debug_package %{nil}
%endif

%if 0%{?rhel}
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
%endif

Name:           wire
Version:        0.6.0
Release:        1.5
Summary:        Compile-time Dependency Injection for Go
License:        Apache-2.0
Group:          Development/Languages/Go
URL:            https://github.com/google/wire
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Patch1:         update_go_version.patch
BuildRequires:  golang(API) >= 1.22
%{?systemd_ordering}
ExcludeArch:    s390

%description
Wire is a code generation tool that automates connecting components using
dependency injection. Dependencies between components are represented in Wire
as function parameters, encouraging explicit initialization instead of global
variables. Because Wire operates without runtime state or reflection, code
written to be used with Wire is useful even for hand-written initialization.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build ./cmd/%{name}

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%if 0%{?rhel} == 8
%check
# Fix OBS debug_package execution.
rm -f %{buildroot}/usr/lib/debug/%{_bindir}/%{name}-%{version}-*.debug
%endif

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Feb 20 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Drop BuildRequires: golang-packaging. The original macros for
    file movements into GOPATH are obsolete with Go modules.
  * Drop autosetup -n arg only needed when archive and package
    name differ
  * Remove goprep macro which is no longer recommended
  * Remove gobuild macro which is no longer recommended
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Remove goinstall macro which is no longer recommended
  * Drop defattr(-,root,root) no longer needed with recent rpm
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Require go 1.22: match what the build declares to need
  go: go.mod requires go >= 1.22 (running go 1.21.7)
* Mon Feb 19 2024 witold.bedyk@suse.com
- Add update_go_version.patch
- Update to version 0.6.0:
  * Add support for Go v1.22.0
  * Update dependencies to support Generics
  * fix: run wire with -mod=mod
  * all: update record/replay files for new version of go
* Mon Apr 24 2023 Marina Latini <marina.latini@suse.com>
- Always require go >= 1.19 (bsc#1203599)
* Wed Mar  8 2023 Marina Latini <marina.latini@suse.com>
- Build with go >= 1.19 on SUSE Linux Enterprise and
  with go1.18 only on SUSE Linux Enterprise 15 SP3. (bsc#1203599)
* Wed Sep 28 2022 Marina Latini <marina.latini@suse.com>
- Require go1.18 (bsc#1203599, GH#19127)
* Thu Jun 16 2022 Julio González Gil <jgonzalez@suse.com>
- Exclude s390 arch
* Tue Feb 15 2022 Witek Bedyk <witold.bedyk@suse.com>
- Refactor conditional golang BuildRequires for RHEL
* Mon Feb 14 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Disabled debug package build for RHEL.
* Fri Feb 11 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Added alternative golang name to build on RHEL.
* Fri Jan 21 2022 Witek Bedyk <witold.bedyk@suse.com>
- Initial package version 0.5.0 (jsc#SLE-23439, jsc#SLE-23422)
